about summary refs log tree commit homepage
path: root/lib
diff options
context:
space:
mode:
authorEric Wong <normalperson@yhbt.net>2010-06-10 19:13:49 -0700
committerEric Wong <normalperson@yhbt.net>2010-06-10 19:13:49 -0700
commit5d53342d6cb7724a3e357551aae358b63b45342c (patch)
treeb2cb9abbcfb3de6d15e8168735296f35f5250f93 /lib
parenteb57310d6130e5d2ce146126a17346f9cba6c49e (diff)
downloadunicorn-5d53342d6cb7724a3e357551aae358b63b45342c.tar.gz
The "working_directory" configuration parameter is now handled
before config.ru.  That means "unicorn" and "unicorn_rails" no
longer barfs when initially started outside of the configured
"working_directory" where a config.ru is required.  A huge
thanks to Pierre Baillet for catching this ugly UI inconsistency
before the big 1.0 release

Thanks to Hongli Lai, out-of-the-box Rails 3 (beta) support
should be improved for deployments lacking a config.ru

There are more new integration tests, cleanups and some
documentation improvements.
Diffstat (limited to 'lib')
-rw-r--r--lib/unicorn/const.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/unicorn/const.rb b/lib/unicorn/const.rb
index 69f4d5f..2ad265a 100644
--- a/lib/unicorn/const.rb
+++ b/lib/unicorn/const.rb
@@ -8,8 +8,8 @@ module Unicorn
   # Symbols did not really improve things much compared to constants.
   module Const
 
-    # The current version of Unicorn, currently 0.990.0
-    UNICORN_VERSION="0.990.0"
+    # The current version of Unicorn, currently 0.991.0
+    UNICORN_VERSION="0.991.0"
 
     DEFAULT_HOST = "0.0.0.0" # default TCP listen host address
     DEFAULT_PORT = 8080      # default TCP listen port